### Name: gpdFit
### Title: Generalized Pareto Distribution Modelling
### Aliases: gpdFit gpdSim print.gpdFit plot.gpdFit summary.gpdFit gpdqPlot
###   gpdquantPlot gpdriskmeasures gpdsfallPlot gpdshapePlot gpdtailPlot
### Keywords: models

### ** Examples

## Load Data:
   data(danish)
   data(bmw)
   
## Simulate GPD Data:
   xmpExtremes("\nStart: Simulate a GPD Distributed Sample > ")
   x = gpdSim(model = list(shape = 0.25, location = 0, scale = 1), n = 1000)
   # Fit GPD Data by Probability Weighted Moments:
   fit = gpdFit(x, nextremes = length(x), type = "pwm") 
   print(fit)
   # Summarize Results:
   par(mfcol = c(4, 2), cex = 0.5)
   summary(fit)  
   
## Fit GPD Data by Max Log Likelihood Method:
   xmpExtremes("\nNext: Estimate Parameters > ")
   fit = gpdFit(x, nextremes = length(x), type = "mle") 
   print(fit)
   # Summarize Results:
   summary(fit) 

## Fit GPD to excess losses over 10 for the 
   xmpExtremes("\nNext: Fit to Excess Losses > ")
   # Danish Fire insurance data:
   fit = gpdFit(danish, 10, type = "mle") 
   print(fit)
   par(mfrow = c(2, 2), cex = 0.7)
   summary(fit)  
   
## Make Example Function:
   xmpExtremes("\nNext: Write Example Function > ")
   examples = function(n) {
     par(mfrow = c(2, 2), cex = 0.7)
   
## gpdqPlot - 
   # Estimate 99.5th percentile:
   # BMW Stock Data: 
     par(mfrow = c(2, 2), cex = 0.7)
     plot(-bmw, ylim = c(0, 0.25), type = "h", main = "BMW Stock Data")
     fit = gpdFit(-bmw, nextremes = floor(length(bmw)/10), type = "mle")
     tail = gpdtailPlot(fit)
     gpdqPlot(tail, 0.995)
     title(main = "BMW: 99.5th Percentile")
 
## gpdqPlot - 
   # Estimates 0f the 99.5th percentile 
   # Danish Fire Data:
     fit = gpdFit(danish, threshold = 10, type = "mle")
     tail = gpdtailPlot(fit)
     gpdqPlot(tail, 0.995)
     title(main = "Danish Data: 99.5th Percentile") }

## gpdquantPlot - 
   # Estimates of the 99.9th percentile:
   # BMW Stock Data
     plot(-bmw, ylim = c(0, 0.25), type = "h", main = "BMW Stock Data")
     gpdquantPlot(-bmw, p = 0.999)
     title(sub = "BMW: GPD High Quantile", cex.sub = 0.75)

## gpdquantPlot - 
   # Estimates of the 99.9th percentile:
   # Danish Fire Data:
     plot(danish, type = "h", main = "Danish Fire")
     gpdquantPlot(danish, p=0.999)
     title(sub = "Danish Fire: GPD High Quantile", cex.sub = 0.75) 
   


